@@ -5,7 +5,7 @@
 #' for imbalancy correction when we have strongly unequal class sizes.
 #' Creates a learner object, which can be
 #' used like any other learner object.
-#' Models can easily be accessed via \code{\link{getHomogeneousEnsembleModels}}.
+#' Models can easily be accessed via \code{\link{getLearnerModel}}.
 #'
 #' OverBagging is implemented as follows:
 #' For each iteration a random data subset is sampled. Minority class examples
@@ -62,9 +62,8 @@ makeOverBaggingWrapper = function(learner, obw.iters = 10L, obw.rate = 1, obw.ma
     makeNumericLearnerParam(id = "obw.rate", lower = 1),
     makeDiscreteLearnerParam(id = "obw.maxcl", c("boot", "all"))
   )
-  x = makeHomogeneousEnsemble(id, "classif", learner, packs, par.set = ps, par.vals = pv,
+  makeHomogeneousEnsemble(id, "classif", learner, packs, par.set = ps, par.vals = pv,
      learner.subclass = c("OverBaggingWrapper", "BaggingWrapper"), model.subclass = "BaggingModel")
-  addProperties(x, "prob")
 }
 
 #' @export
@@ -81,3 +80,7 @@ trainLearner.OverBaggingWrapper = function(.learner, .task, .subset, .weights =
   m = makeHomChainModel(.learner, models)
 }
 
+#' @export
+getLearnerProperties.OverBaggingWrapper = function(learner) {
+  union(getLearnerProperties(learner$next.learner), "prob")
+}
