@@ -8,8 +8,8 @@
 #' @param cl [\code{character(1)}] \cr
 #'   Class name for learner to create.
 #'   By convention, all classification learners start with \dQuote{classif.},
-#'   all regression learners with \dQuote{regr.} and all survival learners
-#'   start with \dQuote{surv.}.
+#'   all regression learners with \dQuote{regr.}, all cluster learners with \dQuote{cluster.}
+#'   and all survival learners start with \dQuote{surv.}.
 #' @param package [\code{character}]\cr
 #'   Package(s) to load for the implementation of the learner.
 #' @param properties [\code{character(1)}]\cr
@@ -21,10 +21,15 @@
 #'     \item{oneclas,twoclass,multiclass}{Can one-class, two-class or multi-class classification problems be handled?}
 #'     \item{prob}{Can probabilites be predicted?}
 #'     \item{se}{Can standard errors be predicted?}
+#'     \item{class.weights}{Can class weights be handled?}
 #'   }
 #'   Default is \code{character(0)}.
+#' @param class.weights.param [\code{character(1)}] \cr
+#'   Name of the parameter, which can be used for providing class weights.
 #' @param par.set [\code{\link[ParamHelpers]{ParamSet}}] \cr
 #'   Parameter set of (hyper)parameters and their constraints.
+#'   Dependent parameters with a \code{requires} field must use \code{quote} and not
+#'   \code{expression} to define it.
 #' @param par.vals [\code{list}] \cr
 #'   Always set hyperparameters to these values when the object is constructed.
 #'   Useful when default values are missing in the underlying function.
@@ -40,10 +45,10 @@
 #' @param note [\code{character(1)}]
 #'   Additional notes regarding the learner and its integration in mlr.
 #'   Default is \dQuote{}.
-#' @return [\code{\link{RLearnerClassif}}, \code{\link{RLearnerRegr}} or \code{\link{RLearnerSurv}}].
+#' @return [\code{\link{RLearnerClassif}}, \code{\link{RLearnerCluster}}, \code{\link{RLearnerMultilabel}} \code{\link{RLearnerRegr}} or \code{\link{RLearnerSurv}}].
 #' @name RLearner
 #' @rdname RLearner
-#' @aliases RLearnerClassif RLearnerRegr RLearnerSurv
+#' @aliases RLearnerClassif RLearnerCluster RLearnerMultilabel RLearnerRegr RLearnerSurv
 NULL
 
 #' @export
@@ -61,7 +66,7 @@ makeRLearnerInternal = function(id, type, package, par.set, par.vals, properties
   requirePackages(package, why = paste("learner", id), default.method = "load")
 
   assertString(id)
-  assertChoice(type, choices = c("classif", "regr", "surv", "cluster"))
+  assertChoice(type, choices = c("classif", "regr", "multilabel", "surv", "cluster"))
   assertSubset(properties, getSupportedLearnerProperties(type))
   assertClass(par.set, classes = "ParamSet")
   checkListElementClass(par.set$pars, "LearnerParam")
@@ -71,28 +76,50 @@ makeRLearnerInternal = function(id, type, package, par.set, par.vals, properties
   assertString(name)
   assertString(short.name)
   assertString(note)
-
-  learner = setClasses(list(
+  learner = makeLearnerBaseConstructor("RLearner",
     id = id,
     type = type,
     package = package,
     properties = unique(properties),
     par.set = par.set,
     par.vals = par.vals,
-    predict.type = "response",
-    name = name,
-    short.name = short.name,
-    note = note
-  ), c("RLearner", "Learner"))
+    predict.type = "response"
+  )
+  learner$name = name
+  learner$short.name = short.name
+  learner$note = note
+  return(learner)
+
 }
 
 #' @export
 #' @rdname RLearner
-makeRLearnerClassif = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "") {
-  addClasses(
+makeRLearnerClassif = function(cl, package, par.set, par.vals = list(), properties = character(0L),
+  name = cl, short.name = cl, note = "", class.weights.param = NULL) {
+
+  lrn = addClasses(
     makeRLearnerInternal(cl, "classif", package, par.set, par.vals, properties, name, short.name, note),
     c(cl, "RLearnerClassif")
   )
+
+  # include the class.weights.param
+  if ("class.weights" %in% getLearnerProperties(lrn)) {
+    assertString(class.weights.param)
+    if (!is.null(par.set$pars[[class.weights.param]]))
+      lrn$class.weights.param = class.weights.param
+    else
+      stopf("'%s' needs to be defined in the parameter set as well.", class.weights.param)
+  }
+  return(lrn)
+}
+
+#' @export
+#' @rdname RLearner
+makeRLearnerMultilabel = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "") {
+  addClasses(
+    makeRLearnerInternal(cl, "multilabel", package, par.set, par.vals, properties, name, short.name, note),
+    c(cl, "RLearnerClassif")
+  )
 }
 
 #' @export
