@@ -7,7 +7,10 @@ makeRLearner.classif.glmboost = function() {
       makeDiscreteLearnerParam(id = "family", default = mboost::Binomial(), values = list(AdaExp = mboost::AdaExp(), Binomial = mboost::Binomial())),
       makeIntegerLearnerParam(id = "mstop", default = 100L, lower = 1L),
       makeNumericLearnerParam(id = "nu", default = 0.1, lower = 0, upper = 1),
+      makeDiscreteLearnerParam(id = "risk", values = c("inbag", "oobag", "none")),
+      makeLogicalLearnerParam(id = "stopintern", default = FALSE),
       makeLogicalLearnerParam(id = "center", default = FALSE),
+      makeLogicalLearnerParam(id = "trace", default = FALSE, tunable = FALSE),
       makeDiscreteLearnerParam(id = "m", default = "mstop", values = c("mstop", "cv", "aic"))
     ),
     par.vals = list(family = mboost::Binomial(), m = "mstop"),
@@ -26,14 +29,14 @@ trainLearner.classif.glmboost = function(.learner, .task, .subset, .weights = NU
   ctrl = learnerArgsToControl(mboost::boost_control, mstop, nu, risk)
   d = getTaskData(.task, .subset)
   if (.learner$predict.type == "prob") {
-    levs = c(.task$task.desc$negative, .task$task.desc$positive)
-    d[, .task$task.desc$target] = factor(d[, .task$task.desc$target], levs)
+    td = getTaskDescription(.task)
+    levs = c(td$negative, td$positive)
+    d[, getTaskTargetNames(.task)] = factor(d[, getTaskTargetNames(.task)], levs)
   }
+  f = getTaskFormula(.task)
   if (is.null(.weights)) {
-    f = as.formula(getTaskFormulaAsString(.task))
     model = mboost::glmboost(f, data = d, control = ctrl, ...)
   } else  {
-    f = as.formula(getTaskFormulaAsString(.task))
     model = mboost::glmboost(f, data = d, control = ctrl, weights = .weights, ...)
   }
   if (m == "cv") {
@@ -49,8 +52,9 @@ predictLearner.classif.glmboost = function(.learner, .model, .newdata, ...) {
   type = ifelse(.learner$predict.type == "response", "class", "response")
   p = predict(.model$learner.model, newdata = .newdata, type = type, ...)
   if (.learner$predict.type  == "prob") {
+    td = .model$task.desc
     p = p[, 1L]
-    levs = c(.model$task.desc$negative, .model$task.desc$positive)
+    levs = c(td$negative, td$positive)
     y = propVectorToMatrix(p, levs)
   } else {
     return(p)
