@@ -5,7 +5,11 @@ makeRLearner.classif.rFerns = function() {
     package = "rFerns",
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "depth", default = 5L),
-      makeIntegerLearnerParam(id = "ferns", default = 1000L)
+      makeIntegerLearnerParam(id = "ferns", default = 1000L),
+      makeLogicalLearnerParam(id = "importance", default = FALSE, tunable = FALSE),
+      makeIntegerLearnerParam(id = "reportErrorEvery", default = 0L, lower = 0L, tunable = FALSE),
+      makeLogicalLearnerParam(id = "saveErrorPropagation", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "saveForest", default = TRUE, tunable = FALSE)
     ),
     properties = c("numerics", "twoclass", "multiclass", "factors", "ordered"),
     name = "Random ferns",
