@@ -6,8 +6,8 @@ makeRLearner.regr.fnn = function() {
     # l is for reject option. cannot be done with mlr atm
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "k", default = 1L, lower = 1L),
-      makeLogicalLearnerParam(id = "use.all", default = TRUE, requires = expression(algorithm == "VR")),
-      makeDiscreteLearnerParam(id = "algorithm", default = "cover_tree", values = list("cover_tree", "kd_tree", "VR"))
+      makeDiscreteLearnerParam(id = "algorithm", default = "cover_tree", 
+        values = list("kd_tree", "cover_tree", "brute"))
     ),
     properties = c("numerics"),
     name = "Fast k-Nearest Neighbor",
