@@ -6,16 +6,17 @@ makeRLearner.regr.nnet = function() {
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "size", default = 3L, lower = 0L),
       makeIntegerLearnerParam(id = "maxit", default = 100L, lower = 1L),
-      makeLogicalLearnerParam(id = "linout", default = FALSE, requires = expression(entropy==FALSE && softmax==FALSE && censored==FALSE)),
-      makeLogicalLearnerParam(id = "entropy", default = FALSE, requires = expression(linout==FALSE && softmax==FALSE && censored==FALSE)),
-      makeLogicalLearnerParam(id = "softmax", default = FALSE, requires = expression(entropy==FALSE && linout==FALSE && censored==FALSE)),
-      makeLogicalLearnerParam(id = "censored", default = FALSE, requires = expression(linout==FALSE && softmax==FALSE && entropy==FALSE)),
+      makeLogicalLearnerParam(id = "linout", default = FALSE, requires = quote(entropy==FALSE && softmax==FALSE && censored==FALSE)),
+      makeLogicalLearnerParam(id = "entropy", default = FALSE, requires = quote(linout==FALSE && softmax==FALSE && censored==FALSE)),
+      makeLogicalLearnerParam(id = "softmax", default = FALSE, requires = quote(entropy==FALSE && linout==FALSE && censored==FALSE)),
+      makeLogicalLearnerParam(id = "censored", default = FALSE, requires = quote(linout==FALSE && softmax==FALSE && entropy==FALSE)),
       makeLogicalLearnerParam(id = "skip", default = FALSE),
       makeNumericLearnerParam(id = "rang", default = 0.7),
       makeNumericLearnerParam(id = "decay", default = 0, lower = 0),
       makeLogicalLearnerParam(id = "Hess", default = FALSE),
-      makeLogicalLearnerParam(id = "trace", default = TRUE),
+      makeLogicalLearnerParam(id = "trace", default = TRUE, tunable = FALSE),
       makeIntegerLearnerParam(id = "MaxNWts", default = 1000L, lower = 1L),
+      # FIXME_PK: Why are abstoll and reltoll written with 2 "l"?
       makeNumericLearnerParam(id = "abstoll", default = 1.0e-4),
       makeNumericLearnerParam(id = "reltoll", default = 1.0e-8)
     ),
@@ -33,7 +34,7 @@ trainLearner.regr.nnet = function(.learner, .task, .subset, .weights = NULL,  ..
     f = getTaskFormula(.task)
     nnet::nnet(f, data = getTaskData(.task, .subset), linout = TRUE, ...)
   } else  {
-    f = as.formula(getTaskFormulaAsString(.task))
+    f = getTaskFormula(.task)
     nnet::nnet(f, data = getTaskData(.task, .subset), linout = TRUE, weights = .weights, ...)
   }
 }
