@@ -21,11 +21,11 @@ makeRLearner.surv.ranger = function() {
       makeIntegerLearnerParam(id = "seed", when = "both", tunable = FALSE),
       makeDiscreteLearnerParam(id = "splitrule", values = c("logrank", "C"), default = "logrank")
     ),
-    par.vals = list(num.threads = 1L),
+    par.vals = list(num.threads = 1L, verbose = FALSE),
     properties = c("numerics", "factors", "rcens", "prob"),
     name = "Random Forests",
     short.name = "ranger",
-    note = ""
+    note = "By default, internal parallelization is switched off (num.threads = 1) and verbose output is disabled. Both settings are changeable."
   )
 }
 
