@@ -14,24 +14,34 @@
 #' @family resample
 NULL
 
+
 makeResamplePrediction = function(instance, preds.test, preds.train) {
-  # FIXME: prealloc
-  data = data.frame()
-  for (i in seq_len(instance$desc$iters)) {
-    if (!is.null(preds.test[[i]]))
-      data = rbind(data, cbind(preds.test[[i]]$data, iter = i, set = "test"))
-    if (!is.null(preds.train[[i]]))
-      data = rbind(data, cbind(preds.train[[i]]$data, iter = i, set = "train"))
-  }
+  tenull = sapply(preds.test, is.null)
+  trnull = sapply(preds.train, is.null)
+  if(any(tenull)) pr.te = preds.test[!tenull] else pr.te = preds.test
+  if(any(trnull)) pr.tr = preds.train[!trnull] else pr.tr = preds.train
+
+  #   dtest = do.call("rbind", lapply(seq_along(pr.te), function(X)
+  #     cbind(pr.te[[X]]$data, iter = X, set = "test") ))
+  #   dtrain = do.call("rbind", lapply(seq_along(pr.tr), function(X)
+  #     cbind(pr.tr[[X]]$data, iter = X, set = "train") ))
+
+  dtest = plyr::rbind.fill(lapply(seq_along(pr.te), function(X)
+    cbind(pr.te[[X]]$data, iter = X, set = "test") ))
+  dtrain = plyr::rbind.fill(lapply(seq_along(pr.tr), function(X)
+    cbind(pr.tr[[X]]$data, iter = X, set = "train") ))
+
+  data = rbind(dtest, dtrain)
+
   p1 = preds.test[[1L]]
-  setClasses(list(
+  makeS3Obj(c("ResamplePrediction", class(p1)),
     instance = instance,
     predict.type = p1$predict.type,
     data = data,
     threshold = p1$threshold,
     task.desc = p1$task.desc,
     time = extractSubList(preds.test, "time")
-  ), c("ResamplePrediction", "Prediction"))
+  )
 }
 
 #' @export
