@@ -6,11 +6,13 @@
 #'   Default is 10.
 #' @export
 #' @rdname TuneControl
-makeTuneControlGrid = function(same.resampling.instance = TRUE, impute.val = NULL, resolution = 10L,
-  tune.threshold = FALSE, tune.threshold.args = list(), log.fun = NULL) {
+makeTuneControlGrid = function(same.resampling.instance = TRUE, impute.val = NULL,
+  resolution = 10L, tune.threshold = FALSE, tune.threshold.args = list(),
+  log.fun = NULL, final.dw.perc = NULL, budget = NULL) {
 
+  resolution = asCount(resolution)
   makeTuneControl(same.resampling.instance = same.resampling.instance, impute.val = impute.val,
     start = NULL, resolution = resolution,
     tune.threshold = tune.threshold, tune.threshold.args = tune.threshold.args,
-    log.fun = log.fun, cl = "TuneControlGrid")
+    log.fun = log.fun, final.dw.perc = final.dw.perc, budget = budget, cl = "TuneControlGrid")
 }
