@@ -35,9 +35,10 @@ test_that("resample", {
   rf4 = setThreshold(rf4, 1)
 
   expect_equal(rf1$data$response, rf2$data$response)
-  f1 = factor(rep(binaryclass.task$task.desc$positive, cv.i$size), levels = binaryclass.task$task.desc$class.levels)
+  td = getTaskDescription(binaryclass.task)
+  f1 = factor(rep(td$positive, cv.i$size), levels = td$class.levels)
   expect_equal(rf3$data$response, f1)
-  f2 = factor(rep(binaryclass.task$task.desc$negative, cv.i$size), levels = binaryclass.task$task.desc$class.levels)
+  f2 = factor(rep(td$negative, cv.i$size), levels = td$class.levels)
   expect_equal(rf4$data$response, f2)
 
   ct = makeClassifTask(data = iris[,c("Species", "Petal.Width")], target = "Species")
@@ -90,7 +91,7 @@ test_that("resample checks constraints", {
 test_that("resample returns errors", {
   configureMlr(on.learner.error = "quiet")
 
-  lrn = makeLearner("classif.mock2", alpha = 1)
+  lrn = makeLearner("classif.__mlrmocklearners__2", alpha = 1)
   z = holdout(lrn, multiclass.task)
   expect_true(!is.na(z$aggr))
   expect_true(is.data.frame(z$err.msgs))
@@ -98,7 +99,7 @@ test_that("resample returns errors", {
   expect_true(all(is.na(z$err.msgs$train)))
   expect_true(all(is.na(z$err.msgs$predict)))
 
-  lrn = makeLearner("classif.mock2", alpha = 0)
+  lrn = makeLearner("classif.__mlrmocklearners__2", alpha = 0)
   m = train(lrn, multiclass.task)
   expect_true(isFailureModel(m))
   z = crossval(lrn, multiclass.task, iters = 2L)
