@@ -16,6 +16,8 @@ test_that("surv_randomForestSRC", {
     parset = parset.list[[i]]
     parset = c(parset, list(data = surv.train, formula = surv.formula, importance = "none", proximity = FALSE, forest = TRUE))
     set.seed(getOption("mlr.debug.seed"))
+    # There are some crazy checks in RFSRC, we have to overwrite the formula here
+    parset$formula = Surv(time, event) ~ .
     m = do.call(randomForestSRC::rfsrc, parset)
     p  = predict(m, newdata = surv.test, importance = "none", na.action = "na.impute")$predicted
     old.predicts.list[[i]] = drop(p)
